@@ -16,6 +16,12 @@ from math import log2
 from time import sleep
 from typing import Tuple, Iterable
 
+from chessengine.exceptions import (
+    PositionError,
+    MoveError,
+    PGNParsingError,
+    GameNodeError,
+)
 from chessengine.moves import (
     get_white_pawn_moves,
     get_white_rook_moves,
@@ -36,6 +42,7 @@ from chessengine.lookup_tables import (
     coords_to_pos,
     pos_to_coords,
     san_piece_map,
+    piece_square_table,
 )
 from chessengine.utils import (
     get_bit_positions,
@@ -139,7 +146,7 @@ class Board:
         self.moves = []
 
     def __repr__(self):
-        piece_list = [" " for _ in range(64)]
+        piece_list = ["." for _ in range(64)]
         unicode_piece = {
             ("white", "kings"): "\u2654",
             ("white", "queens"): "\u2655",
@@ -173,22 +180,20 @@ class Board:
             files = list(reversed(files))
 
         board_repr = ""
-        board_repr += " " + "   ".join(files) + "\n"
+        board_repr += " " + " ".join(files) + "\n"
 
         for i in r:
-            board_repr += "   +---+---+---+---+---+---+---+---+   \n"
-            board_repr += ranks[i] + "  | "
+            board_repr += ranks[i] + "  "
 
             if self.side == "white":
-                board_repr += " | ".join(piece_list[8 * i : 8 * i + 8])
+                board_repr += " ".join(piece_list[8 * i : 8 * i + 8])
             else:
-                board_repr += " | ".join(piece_list[8 * i : 8 * i + 8][::-1])
+                board_repr += " ".join(piece_list[8 * i : 8 * i + 8][::-1])
 
-            board_repr += " |  " + ranks[i]
+            board_repr += "  " + ranks[i]
             board_repr += "\n"
 
-        board_repr += "   +---+---+---+---+---+---+---+---+   \n"
-        board_repr += " " + "   ".join(files) + "\n"
+        board_repr += " " + " ".join(files) + "\n"
         return board_repr
 
     def __str__(self):
@@ -224,22 +229,26 @@ class Board:
         The "score" of the board. A higher/more positive score favors white,
         a lower/more negative score favors black.
         """
-        K = self.piece_count[("white", "kings")]
-        Q = self.piece_count[("white", "queens")]
-        R = self.piece_count[("white", "rooks")]
-        B = self.piece_count[("white", "bishops")]
-        N = self.piece_count[("white", "knights")]
-        P = self.piece_count[("white", "pawns")]
-        k = self.piece_count[("black", "kings")]
-        q = self.piece_count[("black", "queens")]
-        r = self.piece_count[("black", "rooks")]
-        b = self.piece_count[("black", "bishops")]
-        n = self.piece_count[("black", "knights")]
-        p = self.piece_count[("black", "pawns")]
-        s = 200 * (K - k) + 9 * (Q - q) + 5 * (R - r) + 3 * (B - b + N - n) + (P - p)
-        if self.side == "white":
-            return s
-        return -s
+        s = 0
+        piece_values = {
+            "pawns": 100,
+            "rooks": 500,
+            "knights": 320,
+            "bishops": 330,
+            "queens": 900,
+            "kings": 20000,
+        }
+        for i in range(64):
+            pos = 2**i
+            side, piece, _ = self.identify_piece_at(pos)
+            if side is None:
+                continue
+            elif side == "white":
+                s += piece_values[piece] + piece_square_table[(side, piece)][i]
+            else:
+                s -= piece_values[piece] + piece_square_table[(side, piece)][i]
+
+        return s
 
     @property
     def board_pieces(self):
@@ -324,6 +333,7 @@ class Board:
         Returns the bitboard corresponding to the passed piece, considering the board's
         own side. i.e. - If the board is white, calling with piece="king" will return
         white king, etc.
+
         :param piece: Can be one of - "kings", "queens", "bishops", "knights", "rooks", "pawns"
         :return: Bitboard
         """
@@ -391,11 +401,12 @@ class Board:
             the piece identified at position (e.g, "black"), piece is the type of piece identified
             at position (e.g, "bishops"), and bitboard is the bitboard of the piece (e.g, Board.black_bishops).
         """
+        if not position & self.all_pieces:
+            return None, None, None
         for side, piece in self.board:
             board = self.board[(side, piece)]
             if board & position > 0:
                 return side, piece, board
-        return None, None, None
 
     def move(self, start: int, end: int, track: bool = True) -> None:
         """
@@ -416,23 +427,25 @@ class Board:
         :param start: The start position of the move. See :ref:`position_representation`
         :param end: The end position of the move. See :ref:`position_representation`
         :param track: If ``True``, the move made will be stored in self.moves
+
+        :raises PositionError: If an invalid position was passed.
         """
         if not 1 <= start <= 2**63:
-            raise ValueError(
+            raise PositionError(
                 f"The start position is outside the board - moving from {log2(start)} to {log2(end)}"
             )
         if not 1 <= end <= 2**63:
-            raise ValueError(
+            raise PositionError(
                 f"The end position is outside the board - moving from {log2(start)} to {log2(end)}"
             )
 
         start_side, start_piece, start_board = self.identify_piece_at(start)
         if start_side is None:
-            raise ValueError(f"There is no piece at position {log2(start)} to move")
+            raise PositionError(f"There is no piece at position {log2(start)} to move")
 
         end_side, end_piece, end_board = self.identify_piece_at(end)
         if end_side == start_side:
-            raise ValueError(
+            raise PositionError(
                 f"Can't move from {log2(start)} to {log2(end)}, both positions have {end_side} pieces."
             )
 
@@ -478,11 +491,11 @@ class Board:
         if start_piece == "pawns":
             if start_side == "white":
                 # Check en passant status
-                if get_rank(end) - get_rank(start) == 2:
+                if get_rank(start) == 2 and get_rank(end) == 4:
                     self.en_passant_position = start << 8
 
                 # Check if a pawn captured by an en passant move
-                elif get_file(start) != get_file(end):
+                elif end == self.en_passant_position:
                     # White pawn made an en passant move
                     black_pawn_bb = self.get_bitboard("black", "pawns")
                     black_pawn_bb &= clear_position[end >> 8]
@@ -496,11 +509,11 @@ class Board:
 
             else:
                 # Check en passant status
-                if get_rank(start) - get_rank(end) == 2:
+                if get_rank(start) == 7 and get_rank(end) == 5:
                     self.en_passant_position = start >> 8
 
                 # Check if a pawn captured by an en passant move
-                elif get_file(start) != get_file(end):
+                elif end == self.en_passant_position:
                     # Black pawn made an en passant move
                     white_pawn_bb = self.get_bitboard("white", "pawns")
                     white_pawn_bb &= clear_position[end << 8]
@@ -557,15 +570,18 @@ class Board:
         :param start: The start position of the move. See :ref:`position_representation`
         :param end: The end position of the move. See :ref:`position_representation`
         :param track: If ``True``, the move made will be stored in self.moves
+
+        :raises PositionError: If there is not piece at ``start`` to move
+        :raises MoveError: If an invalid move is passed
         """
         side, piece, board = self.identify_piece_at(start)
         if side is None:
-            raise ValueError(
+            raise PositionError(
                 f"There is no piece at {pos_to_coords[int(log2(start))]} to move."
             )
         moves = self.get_moves(side=side, piece=piece)
         if (start, end) not in moves:
-            raise ValueError(
+            raise MoveError(
                 f"{pos_to_coords[int(log2(start))]} to {pos_to_coords[int(log2(end))]} is not a valid move for {side}"
             )
         self.move(start=start, end=end, track=track)
@@ -576,6 +592,9 @@ class Board:
 
         :param move: A move given in SAN
         :param side: "white" or "black"
+
+        :raises MoveError: If an ambiguous or invalid move was passed
+        :raises PGNParsingError: If the move was invalid SAN
         """
         if "0-0-0" in move:
             # queen side castle
@@ -583,7 +602,7 @@ class Board:
                 if self.white_queen_side_castle:
                     self.move(2**4, 2**2)
                 else:
-                    raise ValueError(
+                    raise MoveError(
                         f'White cannot castle, it has already moved the {"rook" if self.white_king_side_castle else "king"}.'
                     )
                 self.white_queen_side_castle = False
@@ -592,7 +611,7 @@ class Board:
                 if self.black_queen_side_castle:
                     self.move(2**60, 2**58)
                 else:
-                    raise ValueError(
+                    raise MoveError(
                         f'Black cannot castle, it has already moved the {"rook" if self.black_king_side_castle else "king"}.'
                     )
                 self.black_queen_side_castle = False
@@ -603,7 +622,7 @@ class Board:
                 if self.white_king_side_castle:
                     self.move(2**4, 2**6)
                 else:
-                    raise ValueError(
+                    raise MoveError(
                         f'White cannot castle, it has already moved the {"rook" if self.white_queen_side_castle else "king"}.'
                     )
                 self.white_king_side_castle = False
@@ -612,7 +631,7 @@ class Board:
                 if self.black_king_side_castle:
                     self.move(2**60, 2**62)
                 else:
-                    raise ValueError(
+                    raise MoveError(
                         f'Black cannot castle, it has already moved the {"rook" if self.black_queen_side_castle else "king"}.'
                     )
                 self.black_king_side_castle = False
@@ -621,7 +640,7 @@ class Board:
             # regular move
             match = SAN_MOVE_REGEX.match(move)
             if match is None:
-                raise ValueError(f'Couldn\'t parse move "{move}".')
+                raise PGNParsingError(f'Couldn\'t parse move "{move}".')
 
             groups = match.groups()
             if groups[0] is None:
@@ -637,12 +656,12 @@ class Board:
                 for m in moves:
                     if m[1] == end_pos:
                         if candidate_move:
-                            raise ValueError(
+                            raise MoveError(
                                 f"{move} is ambiguous for {side}. Specify a file to move from."
                             )
                         candidate_move = m
                 if candidate_move is None:
-                    raise ValueError(f"{move} is not a valid move for {side}.")
+                    raise MoveError(f"{move} is not a valid move for {side}.")
                 else:
                     self.move(start=candidate_move[0], end=candidate_move[1])
             else:
@@ -656,19 +675,19 @@ class Board:
                             and m[1] == end_pos
                         ):
                             if candidate_move:
-                                raise ValueError(
+                                raise MoveError(
                                     f"{move} is ambiguous for {side}. Specify a file as well as rank to move from."
                                 )
                             candidate_move = m
                     if candidate_move is None:
-                        raise ValueError(f"{move} is not a valid move for {side}.")
+                        raise MoveError(f"{move} is not a valid move for {side}.")
                     else:
                         self.move(start=candidate_move[0], end=candidate_move[1])
                 else:
                     # File and rank both present in the SAN
                     start_pos = 2 ** coords_to_pos[groups[1].upper() + groups[2]]
                     if (start_pos, end_pos) not in moves:
-                        raise ValueError(f"{move} is not a valid move for {side}.")
+                        raise MoveError(f"{move} is not a valid move for {side}.")
                     self.move(start=start_pos, end=end_pos)
 
     def make_moves(self, *moves: Iterable[tuple[int, int]]) -> None:
@@ -753,7 +772,6 @@ class Board:
                     ("black", "knights"): get_black_knight_moves,
                     ("black", "pawns"): get_black_pawn_moves,
                 }
-                # TODO - Add support for en passant move detection
                 return move_gens[(side, piece)](self, position)
         else:
             moves = []
@@ -800,8 +818,8 @@ class Board:
     def alpha_beta_search(
         self,
         depth: int = 4,
-        alpha: int = -1000,
-        beta: int = 1000,
+        alpha: int = -100000,
+        beta: int = 100000,
         maximizing_player: bool = True,
     ) -> int:
         """
@@ -819,7 +837,7 @@ class Board:
             return self.score
 
         if maximizing_player:
-            value = -1000
+            value = -100000
             moves = self.get_moves(self.side)
             for move in moves:
                 self.move(start=move[0], end=move[1])
@@ -831,7 +849,7 @@ class Board:
                 alpha = max(alpha, value)
             return value
         else:
-            value = 1000
+            value = 100000
             moves = self.get_moves(self.opponent_side)
             for move in moves:
                 self.move(start=move[0], end=move[1])
@@ -890,7 +908,7 @@ class Board:
                     self.move_san(move=move, side=side_to_move)
                 input_accepted = True
                 last_move = f"{side_to_move.capitalize()} moved {move}"
-            except ValueError as e:
+            except (MoveError, PositionError, PGNParsingError) as e:
                 print(e)
                 lines_added += 1
             except KeyError as e:
@@ -962,7 +980,7 @@ class Board:
                 if in_game_tree:
                     try:
                         current_node = current_node.get_child(move)
-                    except ValueError:
+                    except GameNodeError:
                         in_game_tree = False
                 print(f"You moved {move}")
                 lines_printed += 1
